# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class QueryErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class QueryError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> QueryErrorEnum.QueryError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[QueryErrorEnum.QueryError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, QueryErrorEnum.QueryError]]: ...
        UNSPECIFIED = typing___cast(QueryErrorEnum.QueryError, 0)
        UNKNOWN = typing___cast(QueryErrorEnum.QueryError, 1)
        QUERY_ERROR = typing___cast(QueryErrorEnum.QueryError, 50)
        BAD_ENUM_CONSTANT = typing___cast(QueryErrorEnum.QueryError, 18)
        BAD_ESCAPE_SEQUENCE = typing___cast(QueryErrorEnum.QueryError, 7)
        BAD_FIELD_NAME = typing___cast(QueryErrorEnum.QueryError, 12)
        BAD_LIMIT_VALUE = typing___cast(QueryErrorEnum.QueryError, 15)
        BAD_NUMBER = typing___cast(QueryErrorEnum.QueryError, 5)
        BAD_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 3)
        BAD_PARAMETER_NAME = typing___cast(QueryErrorEnum.QueryError, 61)
        BAD_PARAMETER_VALUE = typing___cast(QueryErrorEnum.QueryError, 62)
        BAD_RESOURCE_TYPE_IN_FROM_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 45)
        BAD_SYMBOL = typing___cast(QueryErrorEnum.QueryError, 2)
        BAD_VALUE = typing___cast(QueryErrorEnum.QueryError, 4)
        DATE_RANGE_TOO_WIDE = typing___cast(QueryErrorEnum.QueryError, 36)
        EXPECTED_AND = typing___cast(QueryErrorEnum.QueryError, 30)
        EXPECTED_BY = typing___cast(QueryErrorEnum.QueryError, 14)
        EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 37)
        EXPECTED_FILTERS_ON_DATE_RANGE = typing___cast(QueryErrorEnum.QueryError, 55)
        EXPECTED_FROM = typing___cast(QueryErrorEnum.QueryError, 44)
        EXPECTED_LIST = typing___cast(QueryErrorEnum.QueryError, 41)
        EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 16)
        EXPECTED_SELECT = typing___cast(QueryErrorEnum.QueryError, 13)
        EXPECTED_SINGLE_VALUE = typing___cast(QueryErrorEnum.QueryError, 42)
        EXPECTED_VALUE_WITH_BETWEEN_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 29)
        INVALID_DATE_FORMAT = typing___cast(QueryErrorEnum.QueryError, 38)
        INVALID_STRING_VALUE = typing___cast(QueryErrorEnum.QueryError, 57)
        INVALID_VALUE_WITH_BETWEEN_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 26)
        INVALID_VALUE_WITH_DURING_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 22)
        INVALID_VALUE_WITH_LIKE_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 56)
        OPERATOR_FIELD_MISMATCH = typing___cast(QueryErrorEnum.QueryError, 35)
        PROHIBITED_EMPTY_LIST_IN_CONDITION = typing___cast(QueryErrorEnum.QueryError, 28)
        PROHIBITED_ENUM_CONSTANT = typing___cast(QueryErrorEnum.QueryError, 54)
        PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 31)
        PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 40)
        PROHIBITED_FIELD_IN_SELECT_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 23)
        PROHIBITED_FIELD_IN_WHERE_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 24)
        PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 43)
        PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 48)
        PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 58)
        PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 49)
        PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 51)
        PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 53)
        LIMIT_VALUE_TOO_LOW = typing___cast(QueryErrorEnum.QueryError, 25)
        PROHIBITED_NEWLINE_IN_STRING = typing___cast(QueryErrorEnum.QueryError, 8)
        PROHIBITED_VALUE_COMBINATION_IN_LIST = typing___cast(QueryErrorEnum.QueryError, 10)
        PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 21)
        STRING_NOT_TERMINATED = typing___cast(QueryErrorEnum.QueryError, 6)
        TOO_MANY_SEGMENTS = typing___cast(QueryErrorEnum.QueryError, 34)
        UNEXPECTED_END_OF_QUERY = typing___cast(QueryErrorEnum.QueryError, 9)
        UNEXPECTED_FROM_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 47)
        UNRECOGNIZED_FIELD = typing___cast(QueryErrorEnum.QueryError, 32)
        UNEXPECTED_INPUT = typing___cast(QueryErrorEnum.QueryError, 11)
        REQUESTED_METRICS_FOR_MANAGER = typing___cast(QueryErrorEnum.QueryError, 59)
    UNSPECIFIED = typing___cast(QueryErrorEnum.QueryError, 0)
    UNKNOWN = typing___cast(QueryErrorEnum.QueryError, 1)
    QUERY_ERROR = typing___cast(QueryErrorEnum.QueryError, 50)
    BAD_ENUM_CONSTANT = typing___cast(QueryErrorEnum.QueryError, 18)
    BAD_ESCAPE_SEQUENCE = typing___cast(QueryErrorEnum.QueryError, 7)
    BAD_FIELD_NAME = typing___cast(QueryErrorEnum.QueryError, 12)
    BAD_LIMIT_VALUE = typing___cast(QueryErrorEnum.QueryError, 15)
    BAD_NUMBER = typing___cast(QueryErrorEnum.QueryError, 5)
    BAD_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 3)
    BAD_PARAMETER_NAME = typing___cast(QueryErrorEnum.QueryError, 61)
    BAD_PARAMETER_VALUE = typing___cast(QueryErrorEnum.QueryError, 62)
    BAD_RESOURCE_TYPE_IN_FROM_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 45)
    BAD_SYMBOL = typing___cast(QueryErrorEnum.QueryError, 2)
    BAD_VALUE = typing___cast(QueryErrorEnum.QueryError, 4)
    DATE_RANGE_TOO_WIDE = typing___cast(QueryErrorEnum.QueryError, 36)
    EXPECTED_AND = typing___cast(QueryErrorEnum.QueryError, 30)
    EXPECTED_BY = typing___cast(QueryErrorEnum.QueryError, 14)
    EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 37)
    EXPECTED_FILTERS_ON_DATE_RANGE = typing___cast(QueryErrorEnum.QueryError, 55)
    EXPECTED_FROM = typing___cast(QueryErrorEnum.QueryError, 44)
    EXPECTED_LIST = typing___cast(QueryErrorEnum.QueryError, 41)
    EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 16)
    EXPECTED_SELECT = typing___cast(QueryErrorEnum.QueryError, 13)
    EXPECTED_SINGLE_VALUE = typing___cast(QueryErrorEnum.QueryError, 42)
    EXPECTED_VALUE_WITH_BETWEEN_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 29)
    INVALID_DATE_FORMAT = typing___cast(QueryErrorEnum.QueryError, 38)
    INVALID_STRING_VALUE = typing___cast(QueryErrorEnum.QueryError, 57)
    INVALID_VALUE_WITH_BETWEEN_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 26)
    INVALID_VALUE_WITH_DURING_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 22)
    INVALID_VALUE_WITH_LIKE_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 56)
    OPERATOR_FIELD_MISMATCH = typing___cast(QueryErrorEnum.QueryError, 35)
    PROHIBITED_EMPTY_LIST_IN_CONDITION = typing___cast(QueryErrorEnum.QueryError, 28)
    PROHIBITED_ENUM_CONSTANT = typing___cast(QueryErrorEnum.QueryError, 54)
    PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 31)
    PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 40)
    PROHIBITED_FIELD_IN_SELECT_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 23)
    PROHIBITED_FIELD_IN_WHERE_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 24)
    PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 43)
    PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 48)
    PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 58)
    PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 49)
    PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 51)
    PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 53)
    LIMIT_VALUE_TOO_LOW = typing___cast(QueryErrorEnum.QueryError, 25)
    PROHIBITED_NEWLINE_IN_STRING = typing___cast(QueryErrorEnum.QueryError, 8)
    PROHIBITED_VALUE_COMBINATION_IN_LIST = typing___cast(QueryErrorEnum.QueryError, 10)
    PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR = typing___cast(QueryErrorEnum.QueryError, 21)
    STRING_NOT_TERMINATED = typing___cast(QueryErrorEnum.QueryError, 6)
    TOO_MANY_SEGMENTS = typing___cast(QueryErrorEnum.QueryError, 34)
    UNEXPECTED_END_OF_QUERY = typing___cast(QueryErrorEnum.QueryError, 9)
    UNEXPECTED_FROM_CLAUSE = typing___cast(QueryErrorEnum.QueryError, 47)
    UNRECOGNIZED_FIELD = typing___cast(QueryErrorEnum.QueryError, 32)
    UNEXPECTED_INPUT = typing___cast(QueryErrorEnum.QueryError, 11)
    REQUESTED_METRICS_FOR_MANAGER = typing___cast(QueryErrorEnum.QueryError, 59)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> QueryErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# Stubs for google.ads.google_ads.v1.proto.services.remarketing_action_service_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class RemarketingActionServiceStub:
    GetRemarketingAction: Any = ...
    MutateRemarketingActions: Any = ...
    def __init__(self, channel: Any) -> None: ...

class RemarketingActionServiceServicer:
    def GetRemarketingAction(self, request: Any, context: Any) -> None: ...
    def MutateRemarketingActions(self, request: Any, context: Any) -> None: ...

def add_RemarketingActionServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.advertising_channel_sub_type_pb2 import (
    AdvertisingChannelSubTypeEnum as google___ads___googleads___v1___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.advertising_channel_type_pb2 import (
    AdvertisingChannelTypeEnum as google___ads___googleads___v1___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.criterion_category_channel_availability_mode_pb2 import (
    CriterionCategoryChannelAvailabilityModeEnum as google___ads___googleads___v1___enums___criterion_category_channel_availability_mode_pb2___CriterionCategoryChannelAvailabilityModeEnum,
)

from google.ads.google_ads.v1.proto.enums.criterion_category_locale_availability_mode_pb2 import (
    CriterionCategoryLocaleAvailabilityModeEnum as google___ads___googleads___v1___enums___criterion_category_locale_availability_mode_pb2___CriterionCategoryLocaleAvailabilityModeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class CriterionCategoryAvailability(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def channel(self) -> CriterionCategoryChannelAvailability: ...

    @property
    def locale(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[CriterionCategoryLocaleAvailability]: ...

    def __init__(self,
        *,
        channel : typing___Optional[CriterionCategoryChannelAvailability] = None,
        locale : typing___Optional[typing___Iterable[CriterionCategoryLocaleAvailability]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CriterionCategoryAvailability: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"channel"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"channel",u"locale"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"channel",b"channel"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"channel",b"channel",u"locale",b"locale"]) -> None: ...

class CriterionCategoryChannelAvailability(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    availability_mode = ... # type: google___ads___googleads___v1___enums___criterion_category_channel_availability_mode_pb2___CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode
    advertising_channel_type = ... # type: google___ads___googleads___v1___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum.AdvertisingChannelType
    advertising_channel_sub_type = ... # type: google___protobuf___internal___containers___RepeatedScalarFieldContainer[google___ads___googleads___v1___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType]

    @property
    def include_default_channel_sub_type(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    def __init__(self,
        *,
        availability_mode : typing___Optional[google___ads___googleads___v1___enums___criterion_category_channel_availability_mode_pb2___CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode] = None,
        advertising_channel_type : typing___Optional[google___ads___googleads___v1___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum.AdvertisingChannelType] = None,
        advertising_channel_sub_type : typing___Optional[typing___Iterable[google___ads___googleads___v1___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType]] = None,
        include_default_channel_sub_type : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CriterionCategoryChannelAvailability: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"include_default_channel_sub_type"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"advertising_channel_sub_type",u"advertising_channel_type",u"availability_mode",u"include_default_channel_sub_type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"include_default_channel_sub_type",b"include_default_channel_sub_type"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"advertising_channel_sub_type",b"advertising_channel_sub_type",u"advertising_channel_type",b"advertising_channel_type",u"availability_mode",b"availability_mode",u"include_default_channel_sub_type",b"include_default_channel_sub_type"]) -> None: ...

class CriterionCategoryLocaleAvailability(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    availability_mode = ... # type: google___ads___googleads___v1___enums___criterion_category_locale_availability_mode_pb2___CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode

    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        availability_mode : typing___Optional[google___ads___googleads___v1___enums___criterion_category_locale_availability_mode_pb2___CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode] = None,
        country_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        language_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CriterionCategoryLocaleAvailability: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"country_code",u"language_code"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"availability_mode",u"country_code",u"language_code"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"country_code",b"country_code",u"language_code",b"language_code"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"availability_mode",b"availability_mode",u"country_code",b"country_code",u"language_code",b"language_code"]) -> None: ...



from google.ads.google_ads.v2.services import enums as enums
from google.ads.google_ads.v2 import types as types

from google.ads.google_ads.v2.services import account_budget_proposal_service_client as account_budget_proposal_service_client
class AccountBudgetProposalServiceClient(account_budget_proposal_service_client.AccountBudgetProposalServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import account_budget_service_client as account_budget_service_client
class AccountBudgetServiceClient(account_budget_service_client.AccountBudgetServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_ad_asset_view_service_client as ad_group_ad_asset_view_service_client
class AdGroupAdAssetViewServiceClient(ad_group_ad_asset_view_service_client.AdGroupAdAssetViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_ad_label_service_client as ad_group_ad_label_service_client
class AdGroupAdLabelServiceClient(ad_group_ad_label_service_client.AdGroupAdLabelServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_ad_service_client as ad_group_ad_service_client
class AdGroupAdServiceClient(ad_group_ad_service_client.AdGroupAdServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_audience_view_service_client as ad_group_audience_view_service_client
class AdGroupAudienceViewServiceClient(ad_group_audience_view_service_client.AdGroupAudienceViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_bid_modifier_service_client as ad_group_bid_modifier_service_client
class AdGroupBidModifierServiceClient(ad_group_bid_modifier_service_client.AdGroupBidModifierServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_criterion_label_service_client as ad_group_criterion_label_service_client
class AdGroupCriterionLabelServiceClient(ad_group_criterion_label_service_client.AdGroupCriterionLabelServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_criterion_service_client as ad_group_criterion_service_client
class AdGroupCriterionServiceClient(ad_group_criterion_service_client.AdGroupCriterionServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_criterion_simulation_service_client as ad_group_criterion_simulation_service_client
class AdGroupCriterionSimulationServiceClient(ad_group_criterion_simulation_service_client.AdGroupCriterionSimulationServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_extension_setting_service_client as ad_group_extension_setting_service_client
class AdGroupExtensionSettingServiceClient(ad_group_extension_setting_service_client.AdGroupExtensionSettingServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_feed_service_client as ad_group_feed_service_client
class AdGroupFeedServiceClient(ad_group_feed_service_client.AdGroupFeedServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_label_service_client as ad_group_label_service_client
class AdGroupLabelServiceClient(ad_group_label_service_client.AdGroupLabelServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_service_client as ad_group_service_client
class AdGroupServiceClient(ad_group_service_client.AdGroupServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_group_simulation_service_client as ad_group_simulation_service_client
class AdGroupSimulationServiceClient(ad_group_simulation_service_client.AdGroupSimulationServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_parameter_service_client as ad_parameter_service_client
class AdParameterServiceClient(ad_parameter_service_client.AdParameterServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_schedule_view_service_client as ad_schedule_view_service_client
class AdScheduleViewServiceClient(ad_schedule_view_service_client.AdScheduleViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import ad_service_client as ad_service_client
class AdServiceClient(ad_service_client.AdServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import age_range_view_service_client as age_range_view_service_client
class AgeRangeViewServiceClient(age_range_view_service_client.AgeRangeViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import asset_service_client as asset_service_client
class AssetServiceClient(asset_service_client.AssetServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import bidding_strategy_service_client as bidding_strategy_service_client
class BiddingStrategyServiceClient(bidding_strategy_service_client.BiddingStrategyServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import billing_setup_service_client as billing_setup_service_client
class BillingSetupServiceClient(billing_setup_service_client.BillingSetupServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_audience_view_service_client as campaign_audience_view_service_client
class CampaignAudienceViewServiceClient(campaign_audience_view_service_client.CampaignAudienceViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_bid_modifier_service_client as campaign_bid_modifier_service_client
class CampaignBidModifierServiceClient(campaign_bid_modifier_service_client.CampaignBidModifierServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_budget_service_client as campaign_budget_service_client
class CampaignBudgetServiceClient(campaign_budget_service_client.CampaignBudgetServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_criterion_service_client as campaign_criterion_service_client
class CampaignCriterionServiceClient(campaign_criterion_service_client.CampaignCriterionServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_criterion_simulation_service_client as campaign_criterion_simulation_service_client
class CampaignCriterionSimulationServiceClient(campaign_criterion_simulation_service_client.CampaignCriterionSimulationServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_draft_service_client as campaign_draft_service_client
class CampaignDraftServiceClient(campaign_draft_service_client.CampaignDraftServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_experiment_service_client as campaign_experiment_service_client
class CampaignExperimentServiceClient(campaign_experiment_service_client.CampaignExperimentServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_extension_setting_service_client as campaign_extension_setting_service_client
class CampaignExtensionSettingServiceClient(campaign_extension_setting_service_client.CampaignExtensionSettingServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_feed_service_client as campaign_feed_service_client
class CampaignFeedServiceClient(campaign_feed_service_client.CampaignFeedServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_label_service_client as campaign_label_service_client
class CampaignLabelServiceClient(campaign_label_service_client.CampaignLabelServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_service_client as campaign_service_client
class CampaignServiceClient(campaign_service_client.CampaignServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import campaign_shared_set_service_client as campaign_shared_set_service_client
class CampaignSharedSetServiceClient(campaign_shared_set_service_client.CampaignSharedSetServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import carrier_constant_service_client as carrier_constant_service_client
class CarrierConstantServiceClient(carrier_constant_service_client.CarrierConstantServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import change_status_service_client as change_status_service_client
class ChangeStatusServiceClient(change_status_service_client.ChangeStatusServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import click_view_service_client as click_view_service_client
class ClickViewServiceClient(click_view_service_client.ClickViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import conversion_action_service_client as conversion_action_service_client
class ConversionActionServiceClient(conversion_action_service_client.ConversionActionServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import conversion_adjustment_upload_service_client as conversion_adjustment_upload_service_client
class ConversionAdjustmentUploadServiceClient(conversion_adjustment_upload_service_client.ConversionAdjustmentUploadServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import conversion_upload_service_client as conversion_upload_service_client
class ConversionUploadServiceClient(conversion_upload_service_client.ConversionUploadServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import customer_client_link_service_client as customer_client_link_service_client
class CustomerClientLinkServiceClient(customer_client_link_service_client.CustomerClientLinkServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import customer_client_service_client as customer_client_service_client
class CustomerClientServiceClient(customer_client_service_client.CustomerClientServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import customer_extension_setting_service_client as customer_extension_setting_service_client
class CustomerExtensionSettingServiceClient(customer_extension_setting_service_client.CustomerExtensionSettingServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import customer_feed_service_client as customer_feed_service_client
class CustomerFeedServiceClient(customer_feed_service_client.CustomerFeedServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import customer_label_service_client as customer_label_service_client
class CustomerLabelServiceClient(customer_label_service_client.CustomerLabelServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import customer_manager_link_service_client as customer_manager_link_service_client
class CustomerManagerLinkServiceClient(customer_manager_link_service_client.CustomerManagerLinkServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import customer_negative_criterion_service_client as customer_negative_criterion_service_client
class CustomerNegativeCriterionServiceClient(customer_negative_criterion_service_client.CustomerNegativeCriterionServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import customer_service_client as customer_service_client
class CustomerServiceClient(customer_service_client.CustomerServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import custom_interest_service_client as custom_interest_service_client
class CustomInterestServiceClient(custom_interest_service_client.CustomInterestServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import detail_placement_view_service_client as detail_placement_view_service_client
class DetailPlacementViewServiceClient(detail_placement_view_service_client.DetailPlacementViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import display_keyword_view_service_client as display_keyword_view_service_client
class DisplayKeywordViewServiceClient(display_keyword_view_service_client.DisplayKeywordViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import distance_view_service_client as distance_view_service_client
class DistanceViewServiceClient(distance_view_service_client.DistanceViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import domain_category_service_client as domain_category_service_client
class DomainCategoryServiceClient(domain_category_service_client.DomainCategoryServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import dynamic_search_ads_search_term_view_service_client as dynamic_search_ads_search_term_view_service_client
class DynamicSearchAdsSearchTermViewServiceClient(dynamic_search_ads_search_term_view_service_client.DynamicSearchAdsSearchTermViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import expanded_landing_page_view_service_client as expanded_landing_page_view_service_client
class ExpandedLandingPageViewServiceClient(expanded_landing_page_view_service_client.ExpandedLandingPageViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import extension_feed_item_service_client as extension_feed_item_service_client
class ExtensionFeedItemServiceClient(extension_feed_item_service_client.ExtensionFeedItemServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import feed_item_service_client as feed_item_service_client
class FeedItemServiceClient(feed_item_service_client.FeedItemServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import feed_item_target_service_client as feed_item_target_service_client
class FeedItemTargetServiceClient(feed_item_target_service_client.FeedItemTargetServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import feed_mapping_service_client as feed_mapping_service_client
class FeedMappingServiceClient(feed_mapping_service_client.FeedMappingServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import feed_placeholder_view_service_client as feed_placeholder_view_service_client
class FeedPlaceholderViewServiceClient(feed_placeholder_view_service_client.FeedPlaceholderViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import feed_service_client as feed_service_client
class FeedServiceClient(feed_service_client.FeedServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import gender_view_service_client as gender_view_service_client
class GenderViewServiceClient(gender_view_service_client.GenderViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import geographic_view_service_client as geographic_view_service_client
class GeographicViewServiceClient(geographic_view_service_client.GeographicViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import geo_target_constant_service_client as geo_target_constant_service_client
class GeoTargetConstantServiceClient(geo_target_constant_service_client.GeoTargetConstantServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import google_ads_field_service_client as google_ads_field_service_client
class GoogleAdsFieldServiceClient(google_ads_field_service_client.GoogleAdsFieldServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import google_ads_service_client as google_ads_service_client
class GoogleAdsServiceClient(google_ads_service_client.GoogleAdsServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import group_placement_view_service_client as group_placement_view_service_client
class GroupPlacementViewServiceClient(group_placement_view_service_client.GroupPlacementViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import hotel_group_view_service_client as hotel_group_view_service_client
class HotelGroupViewServiceClient(hotel_group_view_service_client.HotelGroupViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import hotel_performance_view_service_client as hotel_performance_view_service_client
class HotelPerformanceViewServiceClient(hotel_performance_view_service_client.HotelPerformanceViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import invoice_service_client as invoice_service_client
class InvoiceServiceClient(invoice_service_client.InvoiceServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import keyword_plan_ad_group_service_client as keyword_plan_ad_group_service_client
class KeywordPlanAdGroupServiceClient(keyword_plan_ad_group_service_client.KeywordPlanAdGroupServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import keyword_plan_campaign_service_client as keyword_plan_campaign_service_client
class KeywordPlanCampaignServiceClient(keyword_plan_campaign_service_client.KeywordPlanCampaignServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import keyword_plan_idea_service_client as keyword_plan_idea_service_client
class KeywordPlanIdeaServiceClient(keyword_plan_idea_service_client.KeywordPlanIdeaServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import keyword_plan_keyword_service_client as keyword_plan_keyword_service_client
class KeywordPlanKeywordServiceClient(keyword_plan_keyword_service_client.KeywordPlanKeywordServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import keyword_plan_negative_keyword_service_client as keyword_plan_negative_keyword_service_client
class KeywordPlanNegativeKeywordServiceClient(keyword_plan_negative_keyword_service_client.KeywordPlanNegativeKeywordServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import keyword_plan_service_client as keyword_plan_service_client
class KeywordPlanServiceClient(keyword_plan_service_client.KeywordPlanServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import keyword_view_service_client as keyword_view_service_client
class KeywordViewServiceClient(keyword_view_service_client.KeywordViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import label_service_client as label_service_client
class LabelServiceClient(label_service_client.LabelServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import landing_page_view_service_client as landing_page_view_service_client
class LandingPageViewServiceClient(landing_page_view_service_client.LandingPageViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import language_constant_service_client as language_constant_service_client
class LanguageConstantServiceClient(language_constant_service_client.LanguageConstantServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import location_view_service_client as location_view_service_client
class LocationViewServiceClient(location_view_service_client.LocationViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import managed_placement_view_service_client as managed_placement_view_service_client
class ManagedPlacementViewServiceClient(managed_placement_view_service_client.ManagedPlacementViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import media_file_service_client as media_file_service_client
class MediaFileServiceClient(media_file_service_client.MediaFileServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import merchant_center_link_service_client as merchant_center_link_service_client
class MerchantCenterLinkServiceClient(merchant_center_link_service_client.MerchantCenterLinkServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import mobile_app_category_constant_service_client as mobile_app_category_constant_service_client
class MobileAppCategoryConstantServiceClient(mobile_app_category_constant_service_client.MobileAppCategoryConstantServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import mobile_device_constant_service_client as mobile_device_constant_service_client
class MobileDeviceConstantServiceClient(mobile_device_constant_service_client.MobileDeviceConstantServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import mutate_job_service_client as mutate_job_service_client
class MutateJobServiceClient(mutate_job_service_client.MutateJobServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import operating_system_version_constant_service_client as operating_system_version_constant_service_client
class OperatingSystemVersionConstantServiceClient(operating_system_version_constant_service_client.OperatingSystemVersionConstantServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import paid_organic_search_term_view_service_client as paid_organic_search_term_view_service_client
class PaidOrganicSearchTermViewServiceClient(paid_organic_search_term_view_service_client.PaidOrganicSearchTermViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import parental_status_view_service_client as parental_status_view_service_client
class ParentalStatusViewServiceClient(parental_status_view_service_client.ParentalStatusViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import payments_account_service_client as payments_account_service_client
class PaymentsAccountServiceClient(payments_account_service_client.PaymentsAccountServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import product_bidding_category_constant_service_client as product_bidding_category_constant_service_client
class ProductBiddingCategoryConstantServiceClient(product_bidding_category_constant_service_client.ProductBiddingCategoryConstantServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import product_group_view_service_client as product_group_view_service_client
class ProductGroupViewServiceClient(product_group_view_service_client.ProductGroupViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import reach_plan_service_client as reach_plan_service_client
class ReachPlanServiceClient(reach_plan_service_client.ReachPlanServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import recommendation_service_client as recommendation_service_client
class RecommendationServiceClient(recommendation_service_client.RecommendationServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import remarketing_action_service_client as remarketing_action_service_client
class RemarketingActionServiceClient(remarketing_action_service_client.RemarketingActionServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import search_term_view_service_client as search_term_view_service_client
class SearchTermViewServiceClient(search_term_view_service_client.SearchTermViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import shared_criterion_service_client as shared_criterion_service_client
class SharedCriterionServiceClient(shared_criterion_service_client.SharedCriterionServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import shared_set_service_client as shared_set_service_client
class SharedSetServiceClient(shared_set_service_client.SharedSetServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import shopping_performance_view_service_client as shopping_performance_view_service_client
class ShoppingPerformanceViewServiceClient(shopping_performance_view_service_client.ShoppingPerformanceViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import topic_constant_service_client as topic_constant_service_client
class TopicConstantServiceClient(topic_constant_service_client.TopicConstantServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import topic_view_service_client as topic_view_service_client
class TopicViewServiceClient(topic_view_service_client.TopicViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import user_interest_service_client as user_interest_service_client
class UserInterestServiceClient(user_interest_service_client.UserInterestServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import user_list_service_client as user_list_service_client
class UserListServiceClient(user_list_service_client.UserListServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import user_location_view_service_client as user_location_view_service_client
class UserLocationViewServiceClient(user_location_view_service_client.UserLocationViewServiceClient):
    enums = enums

from google.ads.google_ads.v2.services import video_service_client as video_service_client
class VideoServiceClient(video_service_client.VideoServiceClient):
    enums = enums

from google.ads.google_ads.v2.services.transports import account_budget_proposal_service_grpc_transport as account_budget_proposal_service_grpc_transport
class AccountBudgetProposalServiceGrpcTransport(account_budget_proposal_service_grpc_transport.AccountBudgetProposalServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import account_budget_service_grpc_transport as account_budget_service_grpc_transport
class AccountBudgetServiceGrpcTransport(account_budget_service_grpc_transport.AccountBudgetServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_ad_asset_view_service_grpc_transport as ad_group_ad_asset_view_service_grpc_transport
class AdGroupAdAssetViewServiceGrpcTransport(ad_group_ad_asset_view_service_grpc_transport.AdGroupAdAssetViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_ad_label_service_grpc_transport as ad_group_ad_label_service_grpc_transport
class AdGroupAdLabelServiceGrpcTransport(ad_group_ad_label_service_grpc_transport.AdGroupAdLabelServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_ad_service_grpc_transport as ad_group_ad_service_grpc_transport
class AdGroupAdServiceGrpcTransport(ad_group_ad_service_grpc_transport.AdGroupAdServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_audience_view_service_grpc_transport as ad_group_audience_view_service_grpc_transport
class AdGroupAudienceViewServiceGrpcTransport(ad_group_audience_view_service_grpc_transport.AdGroupAudienceViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_bid_modifier_service_grpc_transport as ad_group_bid_modifier_service_grpc_transport
class AdGroupBidModifierServiceGrpcTransport(ad_group_bid_modifier_service_grpc_transport.AdGroupBidModifierServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_criterion_label_service_grpc_transport as ad_group_criterion_label_service_grpc_transport
class AdGroupCriterionLabelServiceGrpcTransport(ad_group_criterion_label_service_grpc_transport.AdGroupCriterionLabelServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_criterion_service_grpc_transport as ad_group_criterion_service_grpc_transport
class AdGroupCriterionServiceGrpcTransport(ad_group_criterion_service_grpc_transport.AdGroupCriterionServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_criterion_simulation_service_grpc_transport as ad_group_criterion_simulation_service_grpc_transport
class AdGroupCriterionSimulationServiceGrpcTransport(ad_group_criterion_simulation_service_grpc_transport.AdGroupCriterionSimulationServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_extension_setting_service_grpc_transport as ad_group_extension_setting_service_grpc_transport
class AdGroupExtensionSettingServiceGrpcTransport(ad_group_extension_setting_service_grpc_transport.AdGroupExtensionSettingServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_feed_service_grpc_transport as ad_group_feed_service_grpc_transport
class AdGroupFeedServiceGrpcTransport(ad_group_feed_service_grpc_transport.AdGroupFeedServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_label_service_grpc_transport as ad_group_label_service_grpc_transport
class AdGroupLabelServiceGrpcTransport(ad_group_label_service_grpc_transport.AdGroupLabelServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_service_grpc_transport as ad_group_service_grpc_transport
class AdGroupServiceGrpcTransport(ad_group_service_grpc_transport.AdGroupServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_group_simulation_service_grpc_transport as ad_group_simulation_service_grpc_transport
class AdGroupSimulationServiceGrpcTransport(ad_group_simulation_service_grpc_transport.AdGroupSimulationServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_parameter_service_grpc_transport as ad_parameter_service_grpc_transport
class AdParameterServiceGrpcTransport(ad_parameter_service_grpc_transport.AdParameterServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_schedule_view_service_grpc_transport as ad_schedule_view_service_grpc_transport
class AdScheduleViewServiceGrpcTransport(ad_schedule_view_service_grpc_transport.AdScheduleViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import ad_service_grpc_transport as ad_service_grpc_transport
class AdServiceGrpcTransport(ad_service_grpc_transport.AdServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import age_range_view_service_grpc_transport as age_range_view_service_grpc_transport
class AgeRangeViewServiceGrpcTransport(age_range_view_service_grpc_transport.AgeRangeViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import asset_service_grpc_transport as asset_service_grpc_transport
class AssetServiceGrpcTransport(asset_service_grpc_transport.AssetServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import bidding_strategy_service_grpc_transport as bidding_strategy_service_grpc_transport
class BiddingStrategyServiceGrpcTransport(bidding_strategy_service_grpc_transport.BiddingStrategyServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import billing_setup_service_grpc_transport as billing_setup_service_grpc_transport
class BillingSetupServiceGrpcTransport(billing_setup_service_grpc_transport.BillingSetupServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_audience_view_service_grpc_transport as campaign_audience_view_service_grpc_transport
class CampaignAudienceViewServiceGrpcTransport(campaign_audience_view_service_grpc_transport.CampaignAudienceViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_bid_modifier_service_grpc_transport as campaign_bid_modifier_service_grpc_transport
class CampaignBidModifierServiceGrpcTransport(campaign_bid_modifier_service_grpc_transport.CampaignBidModifierServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_budget_service_grpc_transport as campaign_budget_service_grpc_transport
class CampaignBudgetServiceGrpcTransport(campaign_budget_service_grpc_transport.CampaignBudgetServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_criterion_service_grpc_transport as campaign_criterion_service_grpc_transport
class CampaignCriterionServiceGrpcTransport(campaign_criterion_service_grpc_transport.CampaignCriterionServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_criterion_simulation_service_grpc_transport as campaign_criterion_simulation_service_grpc_transport
class CampaignCriterionSimulationServiceGrpcTransport(campaign_criterion_simulation_service_grpc_transport.CampaignCriterionSimulationServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_draft_service_grpc_transport as campaign_draft_service_grpc_transport
class CampaignDraftServiceGrpcTransport(campaign_draft_service_grpc_transport.CampaignDraftServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_experiment_service_grpc_transport as campaign_experiment_service_grpc_transport
class CampaignExperimentServiceGrpcTransport(campaign_experiment_service_grpc_transport.CampaignExperimentServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_extension_setting_service_grpc_transport as campaign_extension_setting_service_grpc_transport
class CampaignExtensionSettingServiceGrpcTransport(campaign_extension_setting_service_grpc_transport.CampaignExtensionSettingServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_feed_service_grpc_transport as campaign_feed_service_grpc_transport
class CampaignFeedServiceGrpcTransport(campaign_feed_service_grpc_transport.CampaignFeedServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_label_service_grpc_transport as campaign_label_service_grpc_transport
class CampaignLabelServiceGrpcTransport(campaign_label_service_grpc_transport.CampaignLabelServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_service_grpc_transport as campaign_service_grpc_transport
class CampaignServiceGrpcTransport(campaign_service_grpc_transport.CampaignServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import campaign_shared_set_service_grpc_transport as campaign_shared_set_service_grpc_transport
class CampaignSharedSetServiceGrpcTransport(campaign_shared_set_service_grpc_transport.CampaignSharedSetServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import carrier_constant_service_grpc_transport as carrier_constant_service_grpc_transport
class CarrierConstantServiceGrpcTransport(carrier_constant_service_grpc_transport.CarrierConstantServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import change_status_service_grpc_transport as change_status_service_grpc_transport
class ChangeStatusServiceGrpcTransport(change_status_service_grpc_transport.ChangeStatusServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import click_view_service_grpc_transport as click_view_service_grpc_transport
class ClickViewServiceGrpcTransport(click_view_service_grpc_transport.ClickViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import conversion_action_service_grpc_transport as conversion_action_service_grpc_transport
class ConversionActionServiceGrpcTransport(conversion_action_service_grpc_transport.ConversionActionServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import conversion_adjustment_upload_service_grpc_transport as conversion_adjustment_upload_service_grpc_transport
class ConversionAdjustmentUploadServiceGrpcTransport(conversion_adjustment_upload_service_grpc_transport.ConversionAdjustmentUploadServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import conversion_upload_service_grpc_transport as conversion_upload_service_grpc_transport
class ConversionUploadServiceGrpcTransport(conversion_upload_service_grpc_transport.ConversionUploadServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import customer_client_link_service_grpc_transport as customer_client_link_service_grpc_transport
class CustomerClientLinkServiceGrpcTransport(customer_client_link_service_grpc_transport.CustomerClientLinkServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import customer_client_service_grpc_transport as customer_client_service_grpc_transport
class CustomerClientServiceGrpcTransport(customer_client_service_grpc_transport.CustomerClientServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import customer_extension_setting_service_grpc_transport as customer_extension_setting_service_grpc_transport
class CustomerExtensionSettingServiceGrpcTransport(customer_extension_setting_service_grpc_transport.CustomerExtensionSettingServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import customer_feed_service_grpc_transport as customer_feed_service_grpc_transport
class CustomerFeedServiceGrpcTransport(customer_feed_service_grpc_transport.CustomerFeedServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import customer_label_service_grpc_transport as customer_label_service_grpc_transport
class CustomerLabelServiceGrpcTransport(customer_label_service_grpc_transport.CustomerLabelServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import customer_manager_link_service_grpc_transport as customer_manager_link_service_grpc_transport
class CustomerManagerLinkServiceGrpcTransport(customer_manager_link_service_grpc_transport.CustomerManagerLinkServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import customer_negative_criterion_service_grpc_transport as customer_negative_criterion_service_grpc_transport
class CustomerNegativeCriterionServiceGrpcTransport(customer_negative_criterion_service_grpc_transport.CustomerNegativeCriterionServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import customer_service_grpc_transport as customer_service_grpc_transport
class CustomerServiceGrpcTransport(customer_service_grpc_transport.CustomerServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import custom_interest_service_grpc_transport as custom_interest_service_grpc_transport
class CustomInterestServiceGrpcTransport(custom_interest_service_grpc_transport.CustomInterestServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import detail_placement_view_service_grpc_transport as detail_placement_view_service_grpc_transport
class DetailPlacementViewServiceGrpcTransport(detail_placement_view_service_grpc_transport.DetailPlacementViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import display_keyword_view_service_grpc_transport as display_keyword_view_service_grpc_transport
class DisplayKeywordViewServiceGrpcTransport(display_keyword_view_service_grpc_transport.DisplayKeywordViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import distance_view_service_grpc_transport as distance_view_service_grpc_transport
class DistanceViewServiceGrpcTransport(distance_view_service_grpc_transport.DistanceViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import domain_category_service_grpc_transport as domain_category_service_grpc_transport
class DomainCategoryServiceGrpcTransport(domain_category_service_grpc_transport.DomainCategoryServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import dynamic_search_ads_search_term_view_service_grpc_transport as dynamic_search_ads_search_term_view_service_grpc_transport
class DynamicSearchAdsSearchTermViewServiceGrpcTransport(dynamic_search_ads_search_term_view_service_grpc_transport.DynamicSearchAdsSearchTermViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import expanded_landing_page_view_service_grpc_transport as expanded_landing_page_view_service_grpc_transport
class ExpandedLandingPageViewServiceGrpcTransport(expanded_landing_page_view_service_grpc_transport.ExpandedLandingPageViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import extension_feed_item_service_grpc_transport as extension_feed_item_service_grpc_transport
class ExtensionFeedItemServiceGrpcTransport(extension_feed_item_service_grpc_transport.ExtensionFeedItemServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import feed_item_service_grpc_transport as feed_item_service_grpc_transport
class FeedItemServiceGrpcTransport(feed_item_service_grpc_transport.FeedItemServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import feed_item_target_service_grpc_transport as feed_item_target_service_grpc_transport
class FeedItemTargetServiceGrpcTransport(feed_item_target_service_grpc_transport.FeedItemTargetServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import feed_mapping_service_grpc_transport as feed_mapping_service_grpc_transport
class FeedMappingServiceGrpcTransport(feed_mapping_service_grpc_transport.FeedMappingServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import feed_placeholder_view_service_grpc_transport as feed_placeholder_view_service_grpc_transport
class FeedPlaceholderViewServiceGrpcTransport(feed_placeholder_view_service_grpc_transport.FeedPlaceholderViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import feed_service_grpc_transport as feed_service_grpc_transport
class FeedServiceGrpcTransport(feed_service_grpc_transport.FeedServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import gender_view_service_grpc_transport as gender_view_service_grpc_transport
class GenderViewServiceGrpcTransport(gender_view_service_grpc_transport.GenderViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import geographic_view_service_grpc_transport as geographic_view_service_grpc_transport
class GeographicViewServiceGrpcTransport(geographic_view_service_grpc_transport.GeographicViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import geo_target_constant_service_grpc_transport as geo_target_constant_service_grpc_transport
class GeoTargetConstantServiceGrpcTransport(geo_target_constant_service_grpc_transport.GeoTargetConstantServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import google_ads_field_service_grpc_transport as google_ads_field_service_grpc_transport
class GoogleAdsFieldServiceGrpcTransport(google_ads_field_service_grpc_transport.GoogleAdsFieldServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import google_ads_service_grpc_transport as google_ads_service_grpc_transport
class GoogleAdsServiceGrpcTransport(google_ads_service_grpc_transport.GoogleAdsServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import group_placement_view_service_grpc_transport as group_placement_view_service_grpc_transport
class GroupPlacementViewServiceGrpcTransport(group_placement_view_service_grpc_transport.GroupPlacementViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import hotel_group_view_service_grpc_transport as hotel_group_view_service_grpc_transport
class HotelGroupViewServiceGrpcTransport(hotel_group_view_service_grpc_transport.HotelGroupViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import hotel_performance_view_service_grpc_transport as hotel_performance_view_service_grpc_transport
class HotelPerformanceViewServiceGrpcTransport(hotel_performance_view_service_grpc_transport.HotelPerformanceViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import invoice_service_grpc_transport as invoice_service_grpc_transport
class InvoiceServiceGrpcTransport(invoice_service_grpc_transport.InvoiceServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import keyword_plan_ad_group_service_grpc_transport as keyword_plan_ad_group_service_grpc_transport
class KeywordPlanAdGroupServiceGrpcTransport(keyword_plan_ad_group_service_grpc_transport.KeywordPlanAdGroupServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import keyword_plan_campaign_service_grpc_transport as keyword_plan_campaign_service_grpc_transport
class KeywordPlanCampaignServiceGrpcTransport(keyword_plan_campaign_service_grpc_transport.KeywordPlanCampaignServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import keyword_plan_idea_service_grpc_transport as keyword_plan_idea_service_grpc_transport
class KeywordPlanIdeaServiceGrpcTransport(keyword_plan_idea_service_grpc_transport.KeywordPlanIdeaServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import keyword_plan_keyword_service_grpc_transport as keyword_plan_keyword_service_grpc_transport
class KeywordPlanKeywordServiceGrpcTransport(keyword_plan_keyword_service_grpc_transport.KeywordPlanKeywordServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import keyword_plan_negative_keyword_service_grpc_transport as keyword_plan_negative_keyword_service_grpc_transport
class KeywordPlanNegativeKeywordServiceGrpcTransport(keyword_plan_negative_keyword_service_grpc_transport.KeywordPlanNegativeKeywordServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import keyword_plan_service_grpc_transport as keyword_plan_service_grpc_transport
class KeywordPlanServiceGrpcTransport(keyword_plan_service_grpc_transport.KeywordPlanServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import keyword_view_service_grpc_transport as keyword_view_service_grpc_transport
class KeywordViewServiceGrpcTransport(keyword_view_service_grpc_transport.KeywordViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import label_service_grpc_transport as label_service_grpc_transport
class LabelServiceGrpcTransport(label_service_grpc_transport.LabelServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import landing_page_view_service_grpc_transport as landing_page_view_service_grpc_transport
class LandingPageViewServiceGrpcTransport(landing_page_view_service_grpc_transport.LandingPageViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import language_constant_service_grpc_transport as language_constant_service_grpc_transport
class LanguageConstantServiceGrpcTransport(language_constant_service_grpc_transport.LanguageConstantServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import location_view_service_grpc_transport as location_view_service_grpc_transport
class LocationViewServiceGrpcTransport(location_view_service_grpc_transport.LocationViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import managed_placement_view_service_grpc_transport as managed_placement_view_service_grpc_transport
class ManagedPlacementViewServiceGrpcTransport(managed_placement_view_service_grpc_transport.ManagedPlacementViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import media_file_service_grpc_transport as media_file_service_grpc_transport
class MediaFileServiceGrpcTransport(media_file_service_grpc_transport.MediaFileServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import merchant_center_link_service_grpc_transport as merchant_center_link_service_grpc_transport
class MerchantCenterLinkServiceGrpcTransport(merchant_center_link_service_grpc_transport.MerchantCenterLinkServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import mobile_app_category_constant_service_grpc_transport as mobile_app_category_constant_service_grpc_transport
class MobileAppCategoryConstantServiceGrpcTransport(mobile_app_category_constant_service_grpc_transport.MobileAppCategoryConstantServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import mobile_device_constant_service_grpc_transport as mobile_device_constant_service_grpc_transport
class MobileDeviceConstantServiceGrpcTransport(mobile_device_constant_service_grpc_transport.MobileDeviceConstantServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import mutate_job_service_grpc_transport as mutate_job_service_grpc_transport
class MutateJobServiceGrpcTransport(mutate_job_service_grpc_transport.MutateJobServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import operating_system_version_constant_service_grpc_transport as operating_system_version_constant_service_grpc_transport
class OperatingSystemVersionConstantServiceGrpcTransport(operating_system_version_constant_service_grpc_transport.OperatingSystemVersionConstantServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import paid_organic_search_term_view_service_grpc_transport as paid_organic_search_term_view_service_grpc_transport
class PaidOrganicSearchTermViewServiceGrpcTransport(paid_organic_search_term_view_service_grpc_transport.PaidOrganicSearchTermViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import parental_status_view_service_grpc_transport as parental_status_view_service_grpc_transport
class ParentalStatusViewServiceGrpcTransport(parental_status_view_service_grpc_transport.ParentalStatusViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import payments_account_service_grpc_transport as payments_account_service_grpc_transport
class PaymentsAccountServiceGrpcTransport(payments_account_service_grpc_transport.PaymentsAccountServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import product_bidding_category_constant_service_grpc_transport as product_bidding_category_constant_service_grpc_transport
class ProductBiddingCategoryConstantServiceGrpcTransport(product_bidding_category_constant_service_grpc_transport.ProductBiddingCategoryConstantServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import product_group_view_service_grpc_transport as product_group_view_service_grpc_transport
class ProductGroupViewServiceGrpcTransport(product_group_view_service_grpc_transport.ProductGroupViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import reach_plan_service_grpc_transport as reach_plan_service_grpc_transport
class ReachPlanServiceGrpcTransport(reach_plan_service_grpc_transport.ReachPlanServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import recommendation_service_grpc_transport as recommendation_service_grpc_transport
class RecommendationServiceGrpcTransport(recommendation_service_grpc_transport.RecommendationServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import remarketing_action_service_grpc_transport as remarketing_action_service_grpc_transport
class RemarketingActionServiceGrpcTransport(remarketing_action_service_grpc_transport.RemarketingActionServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import search_term_view_service_grpc_transport as search_term_view_service_grpc_transport
class SearchTermViewServiceGrpcTransport(search_term_view_service_grpc_transport.SearchTermViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import shared_criterion_service_grpc_transport as shared_criterion_service_grpc_transport
class SharedCriterionServiceGrpcTransport(shared_criterion_service_grpc_transport.SharedCriterionServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import shared_set_service_grpc_transport as shared_set_service_grpc_transport
class SharedSetServiceGrpcTransport(shared_set_service_grpc_transport.SharedSetServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import shopping_performance_view_service_grpc_transport as shopping_performance_view_service_grpc_transport
class ShoppingPerformanceViewServiceGrpcTransport(shopping_performance_view_service_grpc_transport.ShoppingPerformanceViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import topic_constant_service_grpc_transport as topic_constant_service_grpc_transport
class TopicConstantServiceGrpcTransport(topic_constant_service_grpc_transport.TopicConstantServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import topic_view_service_grpc_transport as topic_view_service_grpc_transport
class TopicViewServiceGrpcTransport(topic_view_service_grpc_transport.TopicViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import user_interest_service_grpc_transport as user_interest_service_grpc_transport
class UserInterestServiceGrpcTransport(user_interest_service_grpc_transport.UserInterestServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import user_list_service_grpc_transport as user_list_service_grpc_transport
class UserListServiceGrpcTransport(user_list_service_grpc_transport.UserListServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import user_location_view_service_grpc_transport as user_location_view_service_grpc_transport
class UserLocationViewServiceGrpcTransport(user_location_view_service_grpc_transport.UserLocationViewServiceGrpcTransport):
    ...

from google.ads.google_ads.v2.services.transports import video_service_grpc_transport as video_service_grpc_transport
class VideoServiceGrpcTransport(video_service_grpc_transport.VideoServiceGrpcTransport):
    ...

__all__ = [
    "Types",
    "AccountBudgetProposalServiceClient",
    "AccountBudgetServiceClient",
    "AdGroupAdAssetViewServiceClient",
    "AdGroupAdLabelServiceClient",
    "AdGroupAdServiceClient",
    "AdGroupAudienceViewServiceClient",
    "AdGroupBidModifierServiceClient",
    "AdGroupCriterionLabelServiceClient",
    "AdGroupCriterionServiceClient",
    "AdGroupCriterionSimulationServiceClient",
    "AdGroupExtensionSettingServiceClient",
    "AdGroupFeedServiceClient",
    "AdGroupLabelServiceClient",
    "AdGroupServiceClient",
    "AdGroupSimulationServiceClient",
    "AdParameterServiceClient",
    "AdScheduleViewServiceClient",
    "AdServiceClient",
    "AgeRangeViewServiceClient",
    "AssetServiceClient",
    "BiddingStrategyServiceClient",
    "BillingSetupServiceClient",
    "CampaignAudienceViewServiceClient",
    "CampaignBidModifierServiceClient",
    "CampaignBudgetServiceClient",
    "CampaignCriterionServiceClient",
    "CampaignCriterionSimulationServiceClient",
    "CampaignDraftServiceClient",
    "CampaignExperimentServiceClient",
    "CampaignExtensionSettingServiceClient",
    "CampaignFeedServiceClient",
    "CampaignLabelServiceClient",
    "CampaignServiceClient",
    "CampaignSharedSetServiceClient",
    "CarrierConstantServiceClient",
    "ChangeStatusServiceClient",
    "ClickViewServiceClient",
    "ConversionActionServiceClient",
    "ConversionAdjustmentUploadServiceClient",
    "ConversionUploadServiceClient",
    "CustomerClientLinkServiceClient",
    "CustomerClientServiceClient",
    "CustomerExtensionSettingServiceClient",
    "CustomerFeedServiceClient",
    "CustomerLabelServiceClient",
    "CustomerManagerLinkServiceClient",
    "CustomerNegativeCriterionServiceClient",
    "CustomerServiceClient",
    "CustomInterestServiceClient",
    "DetailPlacementViewServiceClient",
    "DisplayKeywordViewServiceClient",
    "DistanceViewServiceClient",
    "DomainCategoryServiceClient",
    "DynamicSearchAdsSearchTermViewServiceClient",
    "Enums",
    "ExpandedLandingPageViewServiceClient",
    "ExtensionFeedItemServiceClient",
    "FeedItemServiceClient",
    "FeedItemTargetServiceClient",
    "FeedMappingServiceClient",
    "FeedPlaceholderViewServiceClient",
    "FeedServiceClient",
    "GenderViewServiceClient",
    "GeographicViewServiceClient",
    "GeoTargetConstantServiceClient",
    "GoogleAdsFieldServiceClient",
    "GoogleAdsServiceClient",
    "GroupPlacementViewServiceClient",
    "HotelGroupViewServiceClient",
    "HotelPerformanceViewServiceClient",
    "InvoiceServiceClient",
    "KeywordPlanAdGroupServiceClient",
    "KeywordPlanCampaignServiceClient",
    "KeywordPlanIdeaServiceClient",
    "KeywordPlanKeywordServiceClient",
    "KeywordPlanNegativeKeywordServiceClient",
    "KeywordPlanServiceClient",
    "KeywordViewServiceClient",
    "LabelServiceClient",
    "LandingPageViewServiceClient",
    "LanguageConstantServiceClient",
    "LocationViewServiceClient",
    "ManagedPlacementViewServiceClient",
    "MediaFileServiceClient",
    "MerchantCenterLinkServiceClient",
    "MobileAppCategoryConstantServiceClient",
    "MobileDeviceConstantServiceClient",
    "MutateJobServiceClient",
    "OperatingSystemVersionConstantServiceClient",
    "PaidOrganicSearchTermViewServiceClient",
    "ParentalStatusViewServiceClient",
    "PaymentsAccountServiceClient",
    "ProductBiddingCategoryConstantServiceClient",
    "ProductGroupViewServiceClient",
    "ReachPlanServiceClient",
    "RecommendationServiceClient",
    "RemarketingActionServiceClient",
    "SearchTermViewServiceClient",
    "SharedCriterionServiceClient",
    "SharedSetServiceClient",
    "ShoppingPerformanceViewServiceClient",
    "TopicConstantServiceClient",
    "TopicViewServiceClient",
    "UserInterestServiceClient",
    "UserListServiceClient",
    "UserLocationViewServiceClient",
    "VideoServiceClient",
    "AccountBudgetProposalServiceGrpcTransport",
    "AccountBudgetServiceGrpcTransport",
    "AdGroupAdAssetViewServiceGrpcTransport",
    "AdGroupAdLabelServiceGrpcTransport",
    "AdGroupAdServiceGrpcTransport",
    "AdGroupAudienceViewServiceGrpcTransport",
    "AdGroupBidModifierServiceGrpcTransport",
    "AdGroupCriterionLabelServiceGrpcTransport",
    "AdGroupCriterionServiceGrpcTransport",
    "AdGroupCriterionSimulationServiceGrpcTransport",
    "AdGroupExtensionSettingServiceGrpcTransport",
    "AdGroupFeedServiceGrpcTransport",
    "AdGroupLabelServiceGrpcTransport",
    "AdGroupServiceGrpcTransport",
    "AdGroupSimulationServiceGrpcTransport",
    "AdParameterServiceGrpcTransport",
    "AdScheduleViewServiceGrpcTransport",
    "AdServiceGrpcTransport",
    "AgeRangeViewServiceGrpcTransport",
    "AssetServiceGrpcTransport",
    "BiddingStrategyServiceGrpcTransport",
    "BillingSetupServiceGrpcTransport",
    "CampaignAudienceViewServiceGrpcTransport",
    "CampaignBidModifierServiceGrpcTransport",
    "CampaignBudgetServiceGrpcTransport",
    "CampaignCriterionServiceGrpcTransport",
    "CampaignCriterionSimulationServiceGrpcTransport",
    "CampaignDraftServiceGrpcTransport",
    "CampaignExperimentServiceGrpcTransport",
    "CampaignExtensionSettingServiceGrpcTransport",
    "CampaignFeedServiceGrpcTransport",
    "CampaignLabelServiceGrpcTransport",
    "CampaignServiceGrpcTransport",
    "CampaignSharedSetServiceGrpcTransport",
    "CarrierConstantServiceGrpcTransport",
    "ChangeStatusServiceGrpcTransport",
    "ClickViewServiceGrpcTransport",
    "ConversionActionServiceGrpcTransport",
    "ConversionAdjustmentUploadServiceGrpcTransport",
    "ConversionUploadServiceGrpcTransport",
    "CustomerClientLinkServiceGrpcTransport",
    "CustomerClientServiceGrpcTransport",
    "CustomerExtensionSettingServiceGrpcTransport",
    "CustomerFeedServiceGrpcTransport",
    "CustomerLabelServiceGrpcTransport",
    "CustomerManagerLinkServiceGrpcTransport",
    "CustomerNegativeCriterionServiceGrpcTransport",
    "CustomerServiceGrpcTransport",
    "CustomInterestServiceGrpcTransport",
    "DetailPlacementViewServiceGrpcTransport",
    "DisplayKeywordViewServiceGrpcTransport",
    "DistanceViewServiceGrpcTransport",
    "DomainCategoryServiceGrpcTransport",
    "DynamicSearchAdsSearchTermViewServiceGrpcTransport",
    "ExpandedLandingPageViewServiceGrpcTransport",
    "ExtensionFeedItemServiceGrpcTransport",
    "FeedItemServiceGrpcTransport",
    "FeedItemTargetServiceGrpcTransport",
    "FeedMappingServiceGrpcTransport",
    "FeedPlaceholderViewServiceGrpcTransport",
    "FeedServiceGrpcTransport",
    "GenderViewServiceGrpcTransport",
    "GeographicViewServiceGrpcTransport",
    "GeoTargetConstantServiceGrpcTransport",
    "GoogleAdsFieldServiceGrpcTransport",
    "GoogleAdsServiceGrpcTransport",
    "GroupPlacementViewServiceGrpcTransport",
    "HotelGroupViewServiceGrpcTransport",
    "HotelPerformanceViewServiceGrpcTransport",
    "InvoiceServiceGrpcTransport",
    "KeywordPlanAdGroupServiceGrpcTransport",
    "KeywordPlanCampaignServiceGrpcTransport",
    "KeywordPlanIdeaServiceGrpcTransport",
    "KeywordPlanKeywordServiceGrpcTransport",
    "KeywordPlanNegativeKeywordServiceGrpcTransport",
    "KeywordPlanServiceGrpcTransport",
    "KeywordViewServiceGrpcTransport",
    "LabelServiceGrpcTransport",
    "LandingPageViewServiceGrpcTransport",
    "LanguageConstantServiceGrpcTransport",
    "LocationViewServiceGrpcTransport",
    "ManagedPlacementViewServiceGrpcTransport",
    "MediaFileServiceGrpcTransport",
    "MerchantCenterLinkServiceGrpcTransport",
    "MobileAppCategoryConstantServiceGrpcTransport",
    "MobileDeviceConstantServiceGrpcTransport",
    "MutateJobServiceGrpcTransport",
    "OperatingSystemVersionConstantServiceGrpcTransport",
    "PaidOrganicSearchTermViewServiceGrpcTransport",
    "ParentalStatusViewServiceGrpcTransport",
    "PaymentsAccountServiceGrpcTransport",
    "ProductBiddingCategoryConstantServiceGrpcTransport",
    "ProductGroupViewServiceGrpcTransport",
    "ReachPlanServiceGrpcTransport",
    "RecommendationServiceGrpcTransport",
    "RemarketingActionServiceGrpcTransport",
    "SearchTermViewServiceGrpcTransport",
    "SharedCriterionServiceGrpcTransport",
    "SharedSetServiceGrpcTransport",
    "ShoppingPerformanceViewServiceGrpcTransport",
    "TopicConstantServiceGrpcTransport",
    "TopicViewServiceGrpcTransport",
    "UserInterestServiceGrpcTransport",
    "UserListServiceGrpcTransport",
    "UserLocationViewServiceGrpcTransport",
    "VideoServiceGrpcTransport",
]



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ConversionLagBucketEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ConversionLagBucket(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ConversionLagBucketEnum.ConversionLagBucket: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ConversionLagBucketEnum.ConversionLagBucket]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ConversionLagBucketEnum.ConversionLagBucket]]: ...
        UNSPECIFIED = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 0)
        UNKNOWN = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 1)
        LESS_THAN_ONE_DAY = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 2)
        ONE_TO_TWO_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 3)
        TWO_TO_THREE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 4)
        THREE_TO_FOUR_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 5)
        FOUR_TO_FIVE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 6)
        FIVE_TO_SIX_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 7)
        SIX_TO_SEVEN_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 8)
        SEVEN_TO_EIGHT_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 9)
        EIGHT_TO_NINE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 10)
        NINE_TO_TEN_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 11)
        TEN_TO_ELEVEN_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 12)
        ELEVEN_TO_TWELVE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 13)
        TWELVE_TO_THIRTEEN_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 14)
        THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 15)
        FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 16)
        TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 17)
        THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 18)
        FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 19)
        SIXTY_TO_NINETY_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 20)
    UNSPECIFIED = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 0)
    UNKNOWN = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 1)
    LESS_THAN_ONE_DAY = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 2)
    ONE_TO_TWO_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 3)
    TWO_TO_THREE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 4)
    THREE_TO_FOUR_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 5)
    FOUR_TO_FIVE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 6)
    FIVE_TO_SIX_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 7)
    SIX_TO_SEVEN_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 8)
    SEVEN_TO_EIGHT_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 9)
    EIGHT_TO_NINE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 10)
    NINE_TO_TEN_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 11)
    TEN_TO_ELEVEN_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 12)
    ELEVEN_TO_TWELVE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 13)
    TWELVE_TO_THIRTEEN_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 14)
    THIRTEEN_TO_FOURTEEN_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 15)
    FOURTEEN_TO_TWENTY_ONE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 16)
    TWENTY_ONE_TO_THIRTY_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 17)
    THIRTY_TO_FORTY_FIVE_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 18)
    FORTY_FIVE_TO_SIXTY_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 19)
    SIXTY_TO_NINETY_DAYS = typing___cast(ConversionLagBucketEnum.ConversionLagBucket, 20)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ConversionLagBucketEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.criteria_pb2 import (
    AdScheduleInfo as google___ads___googleads___v1___common___criteria_pb2___AdScheduleInfo,
    AgeRangeInfo as google___ads___googleads___v1___common___criteria_pb2___AgeRangeInfo,
    CarrierInfo as google___ads___googleads___v1___common___criteria_pb2___CarrierInfo,
    ContentLabelInfo as google___ads___googleads___v1___common___criteria_pb2___ContentLabelInfo,
    DeviceInfo as google___ads___googleads___v1___common___criteria_pb2___DeviceInfo,
    GenderInfo as google___ads___googleads___v1___common___criteria_pb2___GenderInfo,
    IncomeRangeInfo as google___ads___googleads___v1___common___criteria_pb2___IncomeRangeInfo,
    IpBlockInfo as google___ads___googleads___v1___common___criteria_pb2___IpBlockInfo,
    KeywordInfo as google___ads___googleads___v1___common___criteria_pb2___KeywordInfo,
    LanguageInfo as google___ads___googleads___v1___common___criteria_pb2___LanguageInfo,
    ListingScopeInfo as google___ads___googleads___v1___common___criteria_pb2___ListingScopeInfo,
    LocationGroupInfo as google___ads___googleads___v1___common___criteria_pb2___LocationGroupInfo,
    LocationInfo as google___ads___googleads___v1___common___criteria_pb2___LocationInfo,
    MobileAppCategoryInfo as google___ads___googleads___v1___common___criteria_pb2___MobileAppCategoryInfo,
    MobileApplicationInfo as google___ads___googleads___v1___common___criteria_pb2___MobileApplicationInfo,
    MobileDeviceInfo as google___ads___googleads___v1___common___criteria_pb2___MobileDeviceInfo,
    OperatingSystemVersionInfo as google___ads___googleads___v1___common___criteria_pb2___OperatingSystemVersionInfo,
    ParentalStatusInfo as google___ads___googleads___v1___common___criteria_pb2___ParentalStatusInfo,
    PlacementInfo as google___ads___googleads___v1___common___criteria_pb2___PlacementInfo,
    ProximityInfo as google___ads___googleads___v1___common___criteria_pb2___ProximityInfo,
    TopicInfo as google___ads___googleads___v1___common___criteria_pb2___TopicInfo,
    UserInterestInfo as google___ads___googleads___v1___common___criteria_pb2___UserInterestInfo,
    UserListInfo as google___ads___googleads___v1___common___criteria_pb2___UserListInfo,
    WebpageInfo as google___ads___googleads___v1___common___criteria_pb2___WebpageInfo,
    YouTubeChannelInfo as google___ads___googleads___v1___common___criteria_pb2___YouTubeChannelInfo,
    YouTubeVideoInfo as google___ads___googleads___v1___common___criteria_pb2___YouTubeVideoInfo,
)

from google.ads.google_ads.v1.proto.enums.campaign_criterion_status_pb2 import (
    CampaignCriterionStatusEnum as google___ads___googleads___v1___enums___campaign_criterion_status_pb2___CampaignCriterionStatusEnum,
)

from google.ads.google_ads.v1.proto.enums.criterion_type_pb2 import (
    CriterionTypeEnum as google___ads___googleads___v1___enums___criterion_type_pb2___CriterionTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    FloatValue as google___protobuf___wrappers_pb2___FloatValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class CampaignCriterion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    type = ... # type: google___ads___googleads___v1___enums___criterion_type_pb2___CriterionTypeEnum.CriterionType
    status = ... # type: google___ads___googleads___v1___enums___campaign_criterion_status_pb2___CampaignCriterionStatusEnum.CampaignCriterionStatus

    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def criterion_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___FloatValue: ...

    @property
    def negative(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def keyword(self) -> google___ads___googleads___v1___common___criteria_pb2___KeywordInfo: ...

    @property
    def placement(self) -> google___ads___googleads___v1___common___criteria_pb2___PlacementInfo: ...

    @property
    def mobile_app_category(self) -> google___ads___googleads___v1___common___criteria_pb2___MobileAppCategoryInfo: ...

    @property
    def mobile_application(self) -> google___ads___googleads___v1___common___criteria_pb2___MobileApplicationInfo: ...

    @property
    def location(self) -> google___ads___googleads___v1___common___criteria_pb2___LocationInfo: ...

    @property
    def device(self) -> google___ads___googleads___v1___common___criteria_pb2___DeviceInfo: ...

    @property
    def ad_schedule(self) -> google___ads___googleads___v1___common___criteria_pb2___AdScheduleInfo: ...

    @property
    def age_range(self) -> google___ads___googleads___v1___common___criteria_pb2___AgeRangeInfo: ...

    @property
    def gender(self) -> google___ads___googleads___v1___common___criteria_pb2___GenderInfo: ...

    @property
    def income_range(self) -> google___ads___googleads___v1___common___criteria_pb2___IncomeRangeInfo: ...

    @property
    def parental_status(self) -> google___ads___googleads___v1___common___criteria_pb2___ParentalStatusInfo: ...

    @property
    def user_list(self) -> google___ads___googleads___v1___common___criteria_pb2___UserListInfo: ...

    @property
    def youtube_video(self) -> google___ads___googleads___v1___common___criteria_pb2___YouTubeVideoInfo: ...

    @property
    def youtube_channel(self) -> google___ads___googleads___v1___common___criteria_pb2___YouTubeChannelInfo: ...

    @property
    def proximity(self) -> google___ads___googleads___v1___common___criteria_pb2___ProximityInfo: ...

    @property
    def topic(self) -> google___ads___googleads___v1___common___criteria_pb2___TopicInfo: ...

    @property
    def listing_scope(self) -> google___ads___googleads___v1___common___criteria_pb2___ListingScopeInfo: ...

    @property
    def language(self) -> google___ads___googleads___v1___common___criteria_pb2___LanguageInfo: ...

    @property
    def ip_block(self) -> google___ads___googleads___v1___common___criteria_pb2___IpBlockInfo: ...

    @property
    def content_label(self) -> google___ads___googleads___v1___common___criteria_pb2___ContentLabelInfo: ...

    @property
    def carrier(self) -> google___ads___googleads___v1___common___criteria_pb2___CarrierInfo: ...

    @property
    def user_interest(self) -> google___ads___googleads___v1___common___criteria_pb2___UserInterestInfo: ...

    @property
    def webpage(self) -> google___ads___googleads___v1___common___criteria_pb2___WebpageInfo: ...

    @property
    def operating_system_version(self) -> google___ads___googleads___v1___common___criteria_pb2___OperatingSystemVersionInfo: ...

    @property
    def mobile_device(self) -> google___ads___googleads___v1___common___criteria_pb2___MobileDeviceInfo: ...

    @property
    def location_group(self) -> google___ads___googleads___v1___common___criteria_pb2___LocationGroupInfo: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        campaign : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        criterion_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        bid_modifier : typing___Optional[google___protobuf___wrappers_pb2___FloatValue] = None,
        negative : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        type : typing___Optional[google___ads___googleads___v1___enums___criterion_type_pb2___CriterionTypeEnum.CriterionType] = None,
        status : typing___Optional[google___ads___googleads___v1___enums___campaign_criterion_status_pb2___CampaignCriterionStatusEnum.CampaignCriterionStatus] = None,
        keyword : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___KeywordInfo] = None,
        placement : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___PlacementInfo] = None,
        mobile_app_category : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___MobileAppCategoryInfo] = None,
        mobile_application : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___MobileApplicationInfo] = None,
        location : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___LocationInfo] = None,
        device : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___DeviceInfo] = None,
        ad_schedule : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___AdScheduleInfo] = None,
        age_range : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___AgeRangeInfo] = None,
        gender : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___GenderInfo] = None,
        income_range : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___IncomeRangeInfo] = None,
        parental_status : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___ParentalStatusInfo] = None,
        user_list : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___UserListInfo] = None,
        youtube_video : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___YouTubeVideoInfo] = None,
        youtube_channel : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___YouTubeChannelInfo] = None,
        proximity : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___ProximityInfo] = None,
        topic : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___TopicInfo] = None,
        listing_scope : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___ListingScopeInfo] = None,
        language : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___LanguageInfo] = None,
        ip_block : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___IpBlockInfo] = None,
        content_label : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___ContentLabelInfo] = None,
        carrier : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___CarrierInfo] = None,
        user_interest : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___UserInterestInfo] = None,
        webpage : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___WebpageInfo] = None,
        operating_system_version : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___OperatingSystemVersionInfo] = None,
        mobile_device : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___MobileDeviceInfo] = None,
        location_group : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___LocationGroupInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignCriterion: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_schedule",u"age_range",u"bid_modifier",u"campaign",u"carrier",u"content_label",u"criterion",u"criterion_id",u"device",u"gender",u"income_range",u"ip_block",u"keyword",u"language",u"listing_scope",u"location",u"location_group",u"mobile_app_category",u"mobile_application",u"mobile_device",u"negative",u"operating_system_version",u"parental_status",u"placement",u"proximity",u"topic",u"user_interest",u"user_list",u"webpage",u"youtube_channel",u"youtube_video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_schedule",u"age_range",u"bid_modifier",u"campaign",u"carrier",u"content_label",u"criterion",u"criterion_id",u"device",u"gender",u"income_range",u"ip_block",u"keyword",u"language",u"listing_scope",u"location",u"location_group",u"mobile_app_category",u"mobile_application",u"mobile_device",u"negative",u"operating_system_version",u"parental_status",u"placement",u"proximity",u"resource_name",u"status",u"topic",u"type",u"user_interest",u"user_list",u"webpage",u"youtube_channel",u"youtube_video"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_schedule",b"ad_schedule",u"age_range",b"age_range",u"bid_modifier",b"bid_modifier",u"campaign",b"campaign",u"carrier",b"carrier",u"content_label",b"content_label",u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"device",b"device",u"gender",b"gender",u"income_range",b"income_range",u"ip_block",b"ip_block",u"keyword",b"keyword",u"language",b"language",u"listing_scope",b"listing_scope",u"location",b"location",u"location_group",b"location_group",u"mobile_app_category",b"mobile_app_category",u"mobile_application",b"mobile_application",u"mobile_device",b"mobile_device",u"negative",b"negative",u"operating_system_version",b"operating_system_version",u"parental_status",b"parental_status",u"placement",b"placement",u"proximity",b"proximity",u"topic",b"topic",u"user_interest",b"user_interest",u"user_list",b"user_list",u"webpage",b"webpage",u"youtube_channel",b"youtube_channel",u"youtube_video",b"youtube_video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_schedule",b"ad_schedule",u"age_range",b"age_range",u"bid_modifier",b"bid_modifier",u"campaign",b"campaign",u"carrier",b"carrier",u"content_label",b"content_label",u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"device",b"device",u"gender",b"gender",u"income_range",b"income_range",u"ip_block",b"ip_block",u"keyword",b"keyword",u"language",b"language",u"listing_scope",b"listing_scope",u"location",b"location",u"location_group",b"location_group",u"mobile_app_category",b"mobile_app_category",u"mobile_application",b"mobile_application",u"mobile_device",b"mobile_device",u"negative",b"negative",u"operating_system_version",b"operating_system_version",u"parental_status",b"parental_status",u"placement",b"placement",u"proximity",b"proximity",u"resource_name",b"resource_name",u"status",b"status",u"topic",b"topic",u"type",b"type",u"user_interest",b"user_interest",u"user_list",b"user_list",u"webpage",b"webpage",u"youtube_channel",b"youtube_channel",u"youtube_video",b"youtube_video"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"criterion",b"criterion"]) -> typing_extensions___Literal["keyword","placement","mobile_app_category","mobile_application","location","device","ad_schedule","age_range","gender","income_range","parental_status","user_list","youtube_video","youtube_channel","proximity","topic","listing_scope","language","ip_block","content_label","carrier","user_interest","webpage","operating_system_version","mobile_device","location_group"]: ...



from typing import Any, Optional, Dict, Union
from typing_extensions import Literal
from google.ads.google_ads.config import _ConfigDataUnparsed
from google.oauth2.credentials import Credentials  # type: ignore

_V1 = Literal["v1"]
_V2 = Literal["v2"]

class GoogleAdsClient:
    credentials: Credentials = ...
    developer_token: str = ...
    endpoint: Optional[str] = ...
    login_customer_id: Optional[str] = ...

    @classmethod
    def load_from_env(cls) -> GoogleAdsClient: ...
    @classmethod
    def load_from_string(cls, yaml_str: str) -> GoogleAdsClient: ...
    @classmethod
    def load_from_storage(cls, path: Optional[str] = ...) -> GoogleAdsClient: ...
    @classmethod
    def load_from_dict(cls, config_dict: _ConfigDataUnparsed) -> GoogleAdsClient: ...
    def __init__(self, credentials: Credentials, developer_token: str, endpoint: Optional[str] = ..., login_customer_id: Optional[str] = ..., logging_config: Optional[Dict[Any, Any]] = ...) -> None: ...
    @classmethod
    def get_type(cls, name: str, version: Union[_V1, _V2] = ...) -> Any: ...
    def get_service(self, name: str, version: Union[_V1, _V2] = ...) -> Any: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class CustomerClient(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    @property
    def client_customer(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def hidden(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def level(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def time_zone(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def test_account(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def manager(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def descriptive_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        client_customer : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        hidden : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        level : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        time_zone : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        test_account : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        manager : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        descriptive_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        currency_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CustomerClient: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"client_customer",u"currency_code",u"descriptive_name",u"hidden",u"id",u"level",u"manager",u"test_account",u"time_zone"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"client_customer",u"currency_code",u"descriptive_name",u"hidden",u"id",u"level",u"manager",u"resource_name",u"test_account",u"time_zone"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"client_customer",b"client_customer",u"currency_code",b"currency_code",u"descriptive_name",b"descriptive_name",u"hidden",b"hidden",u"id",b"id",u"level",b"level",u"manager",b"manager",u"test_account",b"test_account",u"time_zone",b"time_zone"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"client_customer",b"client_customer",u"currency_code",b"currency_code",u"descriptive_name",b"descriptive_name",u"hidden",b"hidden",u"id",b"id",u"level",b"level",u"manager",b"manager",u"resource_name",b"resource_name",u"test_account",b"test_account",u"time_zone",b"time_zone"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.matching_function_pb2 import (
    MatchingFunction as google___ads___googleads___v1___common___matching_function_pb2___MatchingFunction,
)

from google.ads.google_ads.v1.proto.enums.feed_link_status_pb2 import (
    FeedLinkStatusEnum as google___ads___googleads___v1___enums___feed_link_status_pb2___FeedLinkStatusEnum,
)

from google.ads.google_ads.v1.proto.enums.placeholder_type_pb2 import (
    PlaceholderTypeEnum as google___ads___googleads___v1___enums___placeholder_type_pb2___PlaceholderTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AdGroupFeed(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    placeholder_types = ... # type: google___protobuf___internal___containers___RepeatedScalarFieldContainer[google___ads___googleads___v1___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderType]
    status = ... # type: google___ads___googleads___v1___enums___feed_link_status_pb2___FeedLinkStatusEnum.FeedLinkStatus

    @property
    def feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def matching_function(self) -> google___ads___googleads___v1___common___matching_function_pb2___MatchingFunction: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        feed : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        placeholder_types : typing___Optional[typing___Iterable[google___ads___googleads___v1___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderType]] = None,
        matching_function : typing___Optional[google___ads___googleads___v1___common___matching_function_pb2___MatchingFunction] = None,
        status : typing___Optional[google___ads___googleads___v1___enums___feed_link_status_pb2___FeedLinkStatusEnum.FeedLinkStatus] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupFeed: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",u"feed",u"matching_function"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",u"feed",u"matching_function",u"placeholder_types",u"resource_name",u"status"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"feed",b"feed",u"matching_function",b"matching_function"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"feed",b"feed",u"matching_function",b"matching_function",u"placeholder_types",b"placeholder_types",u"resource_name",b"resource_name",u"status",b"status"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.tag_snippet_pb2 import (
    TagSnippet as google___ads___googleads___v2___common___tag_snippet_pb2___TagSnippet,
)

from google.ads.google_ads.v2.proto.enums.attribution_model_pb2 import (
    AttributionModelEnum as google___ads___googleads___v2___enums___attribution_model_pb2___AttributionModelEnum,
)

from google.ads.google_ads.v2.proto.enums.conversion_action_category_pb2 import (
    ConversionActionCategoryEnum as google___ads___googleads___v2___enums___conversion_action_category_pb2___ConversionActionCategoryEnum,
)

from google.ads.google_ads.v2.proto.enums.conversion_action_counting_type_pb2 import (
    ConversionActionCountingTypeEnum as google___ads___googleads___v2___enums___conversion_action_counting_type_pb2___ConversionActionCountingTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.conversion_action_status_pb2 import (
    ConversionActionStatusEnum as google___ads___googleads___v2___enums___conversion_action_status_pb2___ConversionActionStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.conversion_action_type_pb2 import (
    ConversionActionTypeEnum as google___ads___googleads___v2___enums___conversion_action_type_pb2___ConversionActionTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.data_driven_model_status_pb2 import (
    DataDrivenModelStatusEnum as google___ads___googleads___v2___enums___data_driven_model_status_pb2___DataDrivenModelStatusEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class ConversionAction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AttributionModelSettings(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        attribution_model = ... # type: google___ads___googleads___v2___enums___attribution_model_pb2___AttributionModelEnum.AttributionModel
        data_driven_model_status = ... # type: google___ads___googleads___v2___enums___data_driven_model_status_pb2___DataDrivenModelStatusEnum.DataDrivenModelStatus

        def __init__(self,
            *,
            attribution_model : typing___Optional[google___ads___googleads___v2___enums___attribution_model_pb2___AttributionModelEnum.AttributionModel] = None,
            data_driven_model_status : typing___Optional[google___ads___googleads___v2___enums___data_driven_model_status_pb2___DataDrivenModelStatusEnum.DataDrivenModelStatus] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> ConversionAction.AttributionModelSettings: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"attribution_model",u"data_driven_model_status"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"attribution_model",b"attribution_model",u"data_driven_model_status",b"data_driven_model_status"]) -> None: ...

    class ValueSettings(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def default_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

        @property
        def default_currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def always_use_default_value(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

        def __init__(self,
            *,
            default_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
            default_currency_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            always_use_default_value : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> ConversionAction.ValueSettings: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"always_use_default_value",u"default_currency_code",u"default_value"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"always_use_default_value",u"default_currency_code",u"default_value"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"always_use_default_value",b"always_use_default_value",u"default_currency_code",b"default_currency_code",u"default_value",b"default_value"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"always_use_default_value",b"always_use_default_value",u"default_currency_code",b"default_currency_code",u"default_value",b"default_value"]) -> None: ...

    resource_name = ... # type: typing___Text
    status = ... # type: google___ads___googleads___v2___enums___conversion_action_status_pb2___ConversionActionStatusEnum.ConversionActionStatus
    type = ... # type: google___ads___googleads___v2___enums___conversion_action_type_pb2___ConversionActionTypeEnum.ConversionActionType
    category = ... # type: google___ads___googleads___v2___enums___conversion_action_category_pb2___ConversionActionCategoryEnum.ConversionActionCategory
    counting_type = ... # type: google___ads___googleads___v2___enums___conversion_action_counting_type_pb2___ConversionActionCountingTypeEnum.ConversionActionCountingType

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def owner_customer(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def include_in_conversions_metric(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    @property
    def click_through_lookback_window_days(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def view_through_lookback_window_days(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def value_settings(self) -> ConversionAction.ValueSettings: ...

    @property
    def attribution_model_settings(self) -> ConversionAction.AttributionModelSettings: ...

    @property
    def tag_snippets(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___tag_snippet_pb2___TagSnippet]: ...

    @property
    def phone_call_duration_seconds(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        status : typing___Optional[google___ads___googleads___v2___enums___conversion_action_status_pb2___ConversionActionStatusEnum.ConversionActionStatus] = None,
        type : typing___Optional[google___ads___googleads___v2___enums___conversion_action_type_pb2___ConversionActionTypeEnum.ConversionActionType] = None,
        category : typing___Optional[google___ads___googleads___v2___enums___conversion_action_category_pb2___ConversionActionCategoryEnum.ConversionActionCategory] = None,
        owner_customer : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        include_in_conversions_metric : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        click_through_lookback_window_days : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        view_through_lookback_window_days : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        value_settings : typing___Optional[ConversionAction.ValueSettings] = None,
        counting_type : typing___Optional[google___ads___googleads___v2___enums___conversion_action_counting_type_pb2___ConversionActionCountingTypeEnum.ConversionActionCountingType] = None,
        attribution_model_settings : typing___Optional[ConversionAction.AttributionModelSettings] = None,
        tag_snippets : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___tag_snippet_pb2___TagSnippet]] = None,
        phone_call_duration_seconds : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        app_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ConversionAction: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"app_id",u"attribution_model_settings",u"click_through_lookback_window_days",u"id",u"include_in_conversions_metric",u"name",u"owner_customer",u"phone_call_duration_seconds",u"value_settings",u"view_through_lookback_window_days"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"app_id",u"attribution_model_settings",u"category",u"click_through_lookback_window_days",u"counting_type",u"id",u"include_in_conversions_metric",u"name",u"owner_customer",u"phone_call_duration_seconds",u"resource_name",u"status",u"tag_snippets",u"type",u"value_settings",u"view_through_lookback_window_days"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"app_id",b"app_id",u"attribution_model_settings",b"attribution_model_settings",u"click_through_lookback_window_days",b"click_through_lookback_window_days",u"id",b"id",u"include_in_conversions_metric",b"include_in_conversions_metric",u"name",b"name",u"owner_customer",b"owner_customer",u"phone_call_duration_seconds",b"phone_call_duration_seconds",u"value_settings",b"value_settings",u"view_through_lookback_window_days",b"view_through_lookback_window_days"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"app_id",b"app_id",u"attribution_model_settings",b"attribution_model_settings",u"category",b"category",u"click_through_lookback_window_days",b"click_through_lookback_window_days",u"counting_type",b"counting_type",u"id",b"id",u"include_in_conversions_metric",b"include_in_conversions_metric",u"name",b"name",u"owner_customer",b"owner_customer",u"phone_call_duration_seconds",b"phone_call_duration_seconds",u"resource_name",b"resource_name",u"status",b"status",u"tag_snippets",b"tag_snippets",u"type",b"type",u"value_settings",b"value_settings",u"view_through_lookback_window_days",b"view_through_lookback_window_days"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CriterionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CriterionType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CriterionTypeEnum.CriterionType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CriterionTypeEnum.CriterionType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CriterionTypeEnum.CriterionType]]: ...
        UNSPECIFIED = typing___cast(CriterionTypeEnum.CriterionType, 0)
        UNKNOWN = typing___cast(CriterionTypeEnum.CriterionType, 1)
        KEYWORD = typing___cast(CriterionTypeEnum.CriterionType, 2)
        PLACEMENT = typing___cast(CriterionTypeEnum.CriterionType, 3)
        MOBILE_APP_CATEGORY = typing___cast(CriterionTypeEnum.CriterionType, 4)
        MOBILE_APPLICATION = typing___cast(CriterionTypeEnum.CriterionType, 5)
        DEVICE = typing___cast(CriterionTypeEnum.CriterionType, 6)
        LOCATION = typing___cast(CriterionTypeEnum.CriterionType, 7)
        LISTING_GROUP = typing___cast(CriterionTypeEnum.CriterionType, 8)
        AD_SCHEDULE = typing___cast(CriterionTypeEnum.CriterionType, 9)
        AGE_RANGE = typing___cast(CriterionTypeEnum.CriterionType, 10)
        GENDER = typing___cast(CriterionTypeEnum.CriterionType, 11)
        INCOME_RANGE = typing___cast(CriterionTypeEnum.CriterionType, 12)
        PARENTAL_STATUS = typing___cast(CriterionTypeEnum.CriterionType, 13)
        YOUTUBE_VIDEO = typing___cast(CriterionTypeEnum.CriterionType, 14)
        YOUTUBE_CHANNEL = typing___cast(CriterionTypeEnum.CriterionType, 15)
        USER_LIST = typing___cast(CriterionTypeEnum.CriterionType, 16)
        PROXIMITY = typing___cast(CriterionTypeEnum.CriterionType, 17)
        TOPIC = typing___cast(CriterionTypeEnum.CriterionType, 18)
        LISTING_SCOPE = typing___cast(CriterionTypeEnum.CriterionType, 19)
        LANGUAGE = typing___cast(CriterionTypeEnum.CriterionType, 20)
        IP_BLOCK = typing___cast(CriterionTypeEnum.CriterionType, 21)
        CONTENT_LABEL = typing___cast(CriterionTypeEnum.CriterionType, 22)
        CARRIER = typing___cast(CriterionTypeEnum.CriterionType, 23)
        USER_INTEREST = typing___cast(CriterionTypeEnum.CriterionType, 24)
        WEBPAGE = typing___cast(CriterionTypeEnum.CriterionType, 25)
        OPERATING_SYSTEM_VERSION = typing___cast(CriterionTypeEnum.CriterionType, 26)
        APP_PAYMENT_MODEL = typing___cast(CriterionTypeEnum.CriterionType, 27)
        MOBILE_DEVICE = typing___cast(CriterionTypeEnum.CriterionType, 28)
        CUSTOM_AFFINITY = typing___cast(CriterionTypeEnum.CriterionType, 29)
        CUSTOM_INTENT = typing___cast(CriterionTypeEnum.CriterionType, 30)
        LOCATION_GROUP = typing___cast(CriterionTypeEnum.CriterionType, 31)
    UNSPECIFIED = typing___cast(CriterionTypeEnum.CriterionType, 0)
    UNKNOWN = typing___cast(CriterionTypeEnum.CriterionType, 1)
    KEYWORD = typing___cast(CriterionTypeEnum.CriterionType, 2)
    PLACEMENT = typing___cast(CriterionTypeEnum.CriterionType, 3)
    MOBILE_APP_CATEGORY = typing___cast(CriterionTypeEnum.CriterionType, 4)
    MOBILE_APPLICATION = typing___cast(CriterionTypeEnum.CriterionType, 5)
    DEVICE = typing___cast(CriterionTypeEnum.CriterionType, 6)
    LOCATION = typing___cast(CriterionTypeEnum.CriterionType, 7)
    LISTING_GROUP = typing___cast(CriterionTypeEnum.CriterionType, 8)
    AD_SCHEDULE = typing___cast(CriterionTypeEnum.CriterionType, 9)
    AGE_RANGE = typing___cast(CriterionTypeEnum.CriterionType, 10)
    GENDER = typing___cast(CriterionTypeEnum.CriterionType, 11)
    INCOME_RANGE = typing___cast(CriterionTypeEnum.CriterionType, 12)
    PARENTAL_STATUS = typing___cast(CriterionTypeEnum.CriterionType, 13)
    YOUTUBE_VIDEO = typing___cast(CriterionTypeEnum.CriterionType, 14)
    YOUTUBE_CHANNEL = typing___cast(CriterionTypeEnum.CriterionType, 15)
    USER_LIST = typing___cast(CriterionTypeEnum.CriterionType, 16)
    PROXIMITY = typing___cast(CriterionTypeEnum.CriterionType, 17)
    TOPIC = typing___cast(CriterionTypeEnum.CriterionType, 18)
    LISTING_SCOPE = typing___cast(CriterionTypeEnum.CriterionType, 19)
    LANGUAGE = typing___cast(CriterionTypeEnum.CriterionType, 20)
    IP_BLOCK = typing___cast(CriterionTypeEnum.CriterionType, 21)
    CONTENT_LABEL = typing___cast(CriterionTypeEnum.CriterionType, 22)
    CARRIER = typing___cast(CriterionTypeEnum.CriterionType, 23)
    USER_INTEREST = typing___cast(CriterionTypeEnum.CriterionType, 24)
    WEBPAGE = typing___cast(CriterionTypeEnum.CriterionType, 25)
    OPERATING_SYSTEM_VERSION = typing___cast(CriterionTypeEnum.CriterionType, 26)
    APP_PAYMENT_MODEL = typing___cast(CriterionTypeEnum.CriterionType, 27)
    MOBILE_DEVICE = typing___cast(CriterionTypeEnum.CriterionType, 28)
    CUSTOM_AFFINITY = typing___cast(CriterionTypeEnum.CriterionType, 29)
    CUSTOM_INTENT = typing___cast(CriterionTypeEnum.CriterionType, 30)
    LOCATION_GROUP = typing___cast(CriterionTypeEnum.CriterionType, 31)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CriterionTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



import grpc  # type: ignore
from google.ads.google_ads.v2.services.transports.billing_setup_service_grpc_transport import BillingSetupServiceGrpcTransport
from google.auth.credentials import Credentials  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from typing import Optional, Dict, Any, List, Sequence, Tuple, Union, Callable, ClassVar
from google.ads.google_ads.v2.proto.resources.billing_setup_pb2 import BillingSetup
from google.ads.google_ads.v2.proto.services.billing_setup_service_pb2 import BillingSetupOperation, MutateBillingSetupResponse

class BillingSetupServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args: Any, **kwargs: Any) -> BillingSetupServiceClient: ...
    @classmethod
    def from_service_account_json(cls, filename: str, *args: Any, **kwargs: Any) -> BillingSetupServiceClient: ...
    @classmethod
    def billing_setup_path(cls, customer: Any, billing_setup: Any) -> str: ...
    transport: Union[BillingSetupServiceGrpcTransport, Callable[[Credentials, type], BillingSetupServiceGrpcTransport]] = ...
    def __init__(self, transport: Optional[Union[BillingSetupServiceGrpcTransport, Callable[[Credentials, type], BillingSetupServiceGrpcTransport]]] = ..., channel: Optional[grpc.Channel] = ..., credentials: Optional[Credentials] = ..., client_config: Optional[Dict[Any, Any]] = ..., client_info: Optional[ClientInfo] = ...) -> None: ...
    def get_billing_setup(self, resource_name: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> BillingSetup: ...
    def mutate_billing_setup(self, customer_id: str, operation_: Union[Dict[Any, Any], BillingSetupOperation], retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> MutateBillingSetupResponse: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.policy_pb2 import (
    PolicyTopicEntry as google___ads___googleads___v2___common___policy_pb2___PolicyTopicEntry,
)

from google.ads.google_ads.v2.proto.enums.asset_field_type_pb2 import (
    AssetFieldTypeEnum as google___ads___googleads___v2___enums___asset_field_type_pb2___AssetFieldTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.asset_performance_label_pb2 import (
    AssetPerformanceLabelEnum as google___ads___googleads___v2___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum,
)

from google.ads.google_ads.v2.proto.enums.policy_approval_status_pb2 import (
    PolicyApprovalStatusEnum as google___ads___googleads___v2___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.policy_review_status_pb2 import (
    PolicyReviewStatusEnum as google___ads___googleads___v2___enums___policy_review_status_pb2___PolicyReviewStatusEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AdGroupAdAssetView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    field_type = ... # type: google___ads___googleads___v2___enums___asset_field_type_pb2___AssetFieldTypeEnum.AssetFieldType
    performance_label = ... # type: google___ads___googleads___v2___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum.AssetPerformanceLabel

    @property
    def ad_group_ad(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def asset(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def policy_summary(self) -> AdGroupAdAssetPolicySummary: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ad_group_ad : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        asset : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        field_type : typing___Optional[google___ads___googleads___v2___enums___asset_field_type_pb2___AssetFieldTypeEnum.AssetFieldType] = None,
        policy_summary : typing___Optional[AdGroupAdAssetPolicySummary] = None,
        performance_label : typing___Optional[google___ads___googleads___v2___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum.AssetPerformanceLabel] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupAdAssetView: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_ad",u"asset",u"policy_summary"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_ad",u"asset",u"field_type",u"performance_label",u"policy_summary",u"resource_name"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_ad",b"ad_group_ad",u"asset",b"asset",u"policy_summary",b"policy_summary"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_ad",b"ad_group_ad",u"asset",b"asset",u"field_type",b"field_type",u"performance_label",b"performance_label",u"policy_summary",b"policy_summary",u"resource_name",b"resource_name"]) -> None: ...

class AdGroupAdAssetPolicySummary(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    review_status = ... # type: google___ads___googleads___v2___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatus
    approval_status = ... # type: google___ads___googleads___v2___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatus

    @property
    def policy_topic_entries(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___policy_pb2___PolicyTopicEntry]: ...

    def __init__(self,
        *,
        policy_topic_entries : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___policy_pb2___PolicyTopicEntry]] = None,
        review_status : typing___Optional[google___ads___googleads___v2___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatus] = None,
        approval_status : typing___Optional[google___ads___googleads___v2___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatus] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupAdAssetPolicySummary: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"approval_status",u"policy_topic_entries",u"review_status"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"approval_status",b"approval_status",u"policy_topic_entries",b"policy_topic_entries",u"review_status",b"review_status"]) -> None: ...
